/**
 * This class tries out the Caesar and Vigenere encoding methods.
 * <p>
 * Before any encoding, a frequency table is displayed for each character
 * in a given message string.  After each encoding, the encoded frequency
 * table is displayed.
 * 
 * @author Alan Williams
 *
 */

import java.util.Scanner;

public class A6Q4
{

	public static void main( String[] args )
	{
        // SET UP KEYBOARD INPUT
        
        Scanner keyboard = new Scanner( System.in );

        // DECLARE VARIABLES / DATA DICTIONARY
        
        String message;			// Message to be encoded
        int[] plainTable;		// Frequency table for message before coding
        int caesarKey;			// Key for Caesar cipher
        String caesarMessage;	// Encoded Caesar message
        int[] caesarTable;		// Frequency table for encoded Caesar message
        String decodedCMessage;	// Decoded Caesar message
        String vigenereKey;		// Key for Vigenere cipher
        String vigenereMessage;	// Encoded Vigenere message
        int[] vigenereTable;	// Frequency table for encoded Vigenere message
        String decodedVMessage; // Decoded Vigenere message
        

		System.out.println( "Enter a message: " );
		message = keyboard.nextLine( );

		System.out.println( "Frequency table for message: " );
		plainTable = Frequency.createFrequencyTable(message);
		printFrequencyTable( plainTable );
		System.out.println( );

		System.out.println( "Enter a Caesar cipher key number: " );
		caesarKey = keyboard.nextInt( );
		keyboard.nextLine( );

		System.out.println( "Your message encoded in the Caesar cipher is: " );
		caesarMessage = Caesar.encode( message, caesarKey );
		System.out.println( caesarMessage );
		System.out.println( );

		System.out.println( "Frequency table for message: " );
		caesarTable = Frequency.createFrequencyTable(caesarMessage);
		printFrequencyTable( caesarTable );
		System.out.println( );

		System.out.println( "The message decoded is : " );
		decodedCMessage = Caesar.decode( caesarMessage, caesarKey );
		System.out.println( decodedCMessage );
		System.out.println( );

		System.out.println( "Enter a Vigenere cipher key phrase: " );
		vigenereKey = keyboard.nextLine( );

		System.out.println( "Your message encoded in the Vigenere cipher is: " );
		vigenereMessage = Vigenere.encode( message, vigenereKey );
		System.out.println( vigenereMessage );
		System.out.println( );

		System.out.println( "Frequency table for message: " );
		vigenereTable = Frequency.createFrequencyTable(vigenereMessage);
		printFrequencyTable( vigenereTable );
		System.out.println( );

		System.out.println( "The message decoded is: " );
		decodedVMessage = Vigenere.decode( vigenereMessage, vigenereKey );
		System.out.println( decodedVMessage );
		System.out.println( );

	}

    // If the 'main' method calls other algorithms, put the method(s) below.

    /**
     * This method displays a frequency table stored in an array of length 26.
     * <p>
     * The value in array position 0 is the frequency of the character 'a', and
     * so on up to array position 25 being the frequency of the character 'z'.
     * <p>
     * Each character, and its corresponding frequency, are displayed.
     * 
     * @param table Array containing character frequencies.
     */
     
	public static void printFrequencyTable( int[] table )
	{
		// DECLARE VARIABLES / DATA DICTIONARY
		
		int index;
		
		// BODY OF ALGORITHM
		
		for ( index = 0; index < 26; index = index + 1 )
		{
			char theChar = ( char ) ( index + 'a' );
			System.out.println( "Character " + theChar + " occurs "
					+ table[index] + " times." );
		}
		
		// RETURN RESULT
		
		return; // void return type
	}

}
