/**
 * ITI 1220 Fall 2005, Assignment 6, Question 1
 * 
 * @author Alan Williams
 */ 

public class Caesar
{

	/**
	 * Decode a message encoded with a specified Caesar shift.
	 * <p>
	 * This method takes a string that is presumed to be a message encoded with
	 * a Caesar shift <code>key</code>, and reverses the encoding. To do
	 * this, all lower case letters are rotated <code>key</code> characters to
	 * the left.
	 * 
	 * @param message
	 *            The string to be decoded
	 * @param key
	 *            A shift of 0 to 25 characters.
	 * @return The decoded message
	 */
	public static String decode( String message, int key )
	{
        // DECLARE VARIABLES/DATA DICTIONARY 

		String result;		// RESULT:  the decoded message
		char messageChar;	// INTERMEDIATE:  one character in the message
		char decodeChar;	// INTERMEDIATE:  decoded character from messageChar
		int index;			// INTERMEDIATE:  current character index
		int letterNumber;	// INTERMEDIATE:  messageChar, relative to 'a' (between 0 and 25)

        // BODY OF ALGORITHM

		// Start with empty decoded message.
		
		result = "";
		index = 0;
		
		// For each character in the encoded message:
		
		while ( index < message.length( ) )
		{
			// Get next character.
			
			messageChar = message.charAt( index );
			
			// See if character is a lower case letter.
			
			if ( messageChar >= 'a' && messageChar <= 'z' )
			{
				// Find relative difference between character and 'a'.
				//
				// Alternative:  (int) messageChar - (int) 'a';
				
				letterNumber = messageChar - 'a';
				
				// Do the shift.  Note that A % B keeps A negative
				// if A < 0.  So, we have to add 26 if necessary.
				
				letterNumber = letterNumber - key;
				if ( letterNumber < 0 )
				{
					letterNumber = letterNumber + 26;
				}
				
				// Convert letterNumber back to a character.
				
				decodeChar = ( char ) ( letterNumber + 'a' );
				
				// Append the decoded character to the decoded message string.
				
				result = result + decodeChar;
			}
			else
			{
				// Character was not a lower case letter.  Pass it through
				// unchanged to the decoded message.
				
				result = result + messageChar;
			}
			
			// Go to next character in encoded message.
			
			index = index + 1;
		}
		
		// RETURN RESULT
		
		return result;
	}

	/**
	 * Encode a message using a specified Caesar shift.
	 * <p>
	 * This method takes a string and encodes it by rotating each lower case
	 * letter in the message <code>key</code> letters ahead in the alphabet.
	 * <p>
	 * @param message The string to be encoded
	 * @param key A shift of 0 to 25 characters.
	 * @return The encoded message
	 */
	public static String encode( String message, int key )
	{
        // DECLARE VARIABLES/DATA DICTIONARY 

		String result;		// RESULT:  the encoded message
		char messageChar;	// INTERMEDIATE:  one character in the message
		char codeChar;		// INTERMEDIATE:  encoded character from messageChar
		int index;			// INTERMEDIATE:  current character index
		int letterNumber;	// INTERMEDIATE:  messageChar, relative to 'a' (between 0 and 25)

        // BODY OF ALGORITHM

		result = "";
		index = 0;

		// For each character in the message:
		
		while ( index < message.length( ) )
		{
			// Get next character.
			
			messageChar = message.charAt( index );
			
			// See if character is a lower case letter.
			
			if ( messageChar >= 'a' && messageChar <= 'z' )
			{
				// Find relative difference between character and 'a'.
				//
				// Alternative:  (int) messageChar - (int) 'a';
				
				letterNumber = messageChar - 'a';
				
				// Do the shift.  Note that the % 26 keeps us
				// within range of the alphabet.
				
				letterNumber = ( letterNumber + key ) % 26;
				
				// Convert letterNumber back to a character.
				
				codeChar = ( char ) ( letterNumber + 'a' );
				
				// Append the encoded character to the encoded message string.
				
				result = result + codeChar;
			}
			else
			{
				// Character was not a lower case letter.  Pass it through
				// unchanged to the encoded message.
				
				result = result + messageChar;
			}
			
			// Go to next character in message.
			
			index = index + 1;
		}
		
		// RETURN RESULT
		
		return result;
	}

}
